from setuptools import setup

setup(name='sqlIite',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['sqlIite'],
      author_email='fw3fsw@yandex.ru',
      zip_safe=False)
